%global pkg_name automation-eda-controller
%global pypi_name aap-eda
%global module_name aap_eda
%global pkg_user eda
%global ui_name aap-ui
%global assets_name controller-assets

%global aap_version 2.4
%global commitId 54fa3b12d60bb44d88c67d8dea218ea3a00e0fea
%global commitId_ui 000f4fd10106d31e789dfadf0a4e8d69e250361f
%global commitId_assets 323ea2058b8a366d2a25b41488ceff706ee1f3cd

%global common_description %{expand:
Event Driven Ansible for AAP}
%global common_summary %{expand: Event Driven Ansible for AAP}


Name:           %{pkg_name}
Version:        1.0.0
Release:        1%{?dist}
Summary:        %{common_summary}

License:        Apache-2.0
URL:            git@github.com:ansible/aap-eda.git
Source0:        automation-eda-controller-54fa3b12d60bb44d88c67d8dea218ea3a00e0fea.tar.gz
Source1:        aap-ui-000f4fd10106d31e789dfadf0a4e8d69e250361f.tar.gz
Source2:        controller-assets-323ea2058b8a366d2a25b41488ceff706ee1f3cd.tar.gz
Source3:        js_bundled_dep.txt
Source10:       automation-eda-controller.service
Source11:       automation-eda-controller-worker@.service
Source12:       automation-eda-controller.socket
Source13:       automation-eda-controller-daphne.service
Source14:       automation-eda-controller-worker.target
Source15:       automation-eda-controller.target
Source20:       automation-eda-controller-tmpfiles.conf
Source21:       50-automation-eda-controller-rsyslog.conf
Source22:       automation-eda-controller-logrotate.conf
Patch0:         01-remove-poetry-groups.patch

BuildArch:      noarch

BuildRequires:  nodejs-devel
BuildRequires:  npm
BuildRequires:  python%{python3_pkgversion}-devel
BuildRequires:  python%{python3_pkgversion}-rpm-macros
BuildRequires:  python%{python3_pkgversion}-setuptools
BuildRequires:  python%{python3_pkgversion}-pip
BuildRequires:  python%{python3_pkgversion}-wheel
BuildRequires:  python%{python3_pkgversion}-poetry-core
BuildRequires:  systemd

Requires:       automation-eda-controller-server = %{version}-%{release}
Requires:       automation-eda-controller-ui = %{version}-%{release}
Requires:       crun
Requires:       logrotate
Requires:       podman
Requires:       postgresql
# SELinux requirements
Requires:       python3-libsemanage
Requires:       redis
Requires:       rsyslog
Requires:       systemd

%description
%{common_description}

%package server

Summary:        Event Driven Ansible Server and API

Requires:       ansible-automation-platform-common = %{aap_version}
Requires:       ansible-rulebook
Requires:       git-core
Requires:       python%{python3_pkgversion}-channels+daphne
Requires:       python%{python3_pkgversion}-cryptography
Requires:       python%{python3_pkgversion}-django < 4
Requires:       python%{python3_pkgversion}-djangorestframework
Requires:       python%{python3_pkgversion}-django-filter
Requires:       python%{python3_pkgversion}-django-rq
Requires:       python%{python3_pkgversion}-drf-spectacular
Requires:       python%{python3_pkgversion}-dynaconf >= 3
Requires:       python%{python3_pkgversion}-gunicorn
Requires:       python%{python3_pkgversion}-kubernetes
Requires:       python%{python3_pkgversion}-podman >= 3:4.5
Requires:       python%{python3_pkgversion}-psycopg2
Requires:       python%{python3_pkgversion}-pydantic
Requires:       python%{python3_pkgversion}-rq

%description server
Event Driven Ansible for AAP server and API

%package ui

Summary:        Event Driven Ansible UI

Requires:       ansible-automation-platform-common = %{aap_version}
Requires:       nginx >= 1:1.18.0

# JS dependencies
%include %{SOURCE3}

%description ui
Event Driven Ansible for AAP UI

%prep
%setup -q -T -b 1 -n %{ui_name}-%{commitId_ui}
%setup -q -T -b 2 -n %{assets_name}-%{commitId_assets}
%setup -q -n %{pkg_name}-%{commitId}
%patch -P 0 -p1

cat <<EOF >> setup.cfg

[metadata]
name = %{pypi_name}
version = %{version}
author = Red Hat, Inc.
author_email = info@ansible.com
url = %{url}
project_urls =
  Source Code = %{url}
license = %{license}
license_files = LICENSE
description = Event Driven Ansible for AAP
long_description = file: README.md
long_description_content_type = text/markdown
classifiers =
  Programming Language :: Python :: 3
  Programming Language :: Python :: 3.9
  Programming Language :: Python :: 3.10
  License :: OSI Approved :: Apache Software License
  Operating System :: OS Independent

[options]
install_requires =
    django < 4
    djangorestframework
    dynaconf >= 3
    drf-spectacular
    channels[daphne]
    psycopg2
    django-rq
    rq
    django-filter
    pydantic
    cryptography
    kubernetes
    podman >= 4.5
python_requires = >=3.9
packages = find:
package_dir =
    = src
include_package_data = True

[options.entry_points]
console_scripts =
    aap-eda-manage = aap_eda.manage:main

[options.packages.find]
where = src
EOF

%py3_shebang_fix src/aap_eda

%build

# build server
# Taken from pyproject-rpm-macros's 'pyproject_wheel'
%{__python3} -m pip wheel --wheel-dir %{_builddir}/wheeldir --no-deps --use-pep517 --no-build-isolation --disable-pip-version-check --no-clean --progress-bar off --verbose .

# init npm
npm_registry_override="https://repository.engineering.redhat.com/nexus/repository/registry.npmjs.org/"
npm config set registry ${npm_registry_override}
npm config set strict-ssl false

# build ui
cd %{_builddir}/%{ui_name}-%{commitId_ui}

cp %{_builddir}/%{assets_name}-%{commitId_assets}/awx/ui/client/assets/* frontend/icons/

export BRAND="Red Hat"
export PRODUCT="Ansible Automation Platform"
export VERSION=%{aap_version}

CYPRESS_INSTALL_BINARY=0 npm install --build-from-source
npm run build:eda

%install

install -m 0755 -vd                     %{buildroot}%{_unitdir}

# add system unit files
install -m 644 %{SOURCE10}              %{buildroot}%{_unitdir}
install -m 644 %{SOURCE11}              %{buildroot}%{_unitdir}
install -m 644 %{SOURCE12}              %{buildroot}%{_unitdir}
install -m 644 %{SOURCE13}              %{buildroot}%{_unitdir}
install -m 644 %{SOURCE14}              %{buildroot}%{_unitdir}
install -m 644 %{SOURCE15}              %{buildroot}%{_unitdir}

# add tmpfiles.d for socket files
install -m 0755 -vd                     %{buildroot}%{_sysconfdir}/tmpfiles.d
install -m 640 %{SOURCE20}              %{buildroot}%{_sysconfdir}/tmpfiles.d/automation-eda-controller.conf

# add rsyslog config
install -m 0755 -vd                     %{buildroot}%{_sysconfdir}/rsyslog.d
install -m 644 %{SOURCE21}              %{buildroot}%{_sysconfdir}/rsyslog.d/50-automation-eda-controller.conf

# add logrotate config
install -m 0755 -vd                     %{buildroot}%{_sysconfdir}/logrotate.d
install -m 644 %{SOURCE22}              %{buildroot}%{_sysconfdir}/logrotate.d/automation-eda-controller

# add configuration directory
mkdir -p %{buildroot}%{_sysconfdir}/ansible-automation-platform/eda

# add EDA shared state, media, and home dir
mkdir -p %{buildroot}%{_sharedstatedir}/ansible-automation-platform/eda/media

# add log directory
mkdir -p %{buildroot}%{_localstatedir}/log/ansible-automation-platform/eda

#install ui
mkdir -p %{buildroot}%{_sharedstatedir}/ansible-automation-platform/eda/ui
cp -a %{_builddir}/%{ui_name}-%{commitId_ui}/build/eda/* %{buildroot}%{_sharedstatedir}/ansible-automation-platform/eda/ui

# add directory for sockets
mkdir -p %{buildroot}%{_rundir}/ansible-automation-platform/eda

#install server

# Taken from pyproject-rpm-macros's 'pyproject_wheel'
%{__python3} -m pip install --root %{buildroot} --no-deps --disable-pip-version-check --progress-bar off --verbose --ignore-installed --no-warn-script-location --no-index --no-cache-dir --find-links %{_builddir}/wheeldir %{pypi_name}==%{version}
sed -i 's/pip/rpm/' %{buildroot}/%{python3_sitelib}/%{module_name}-%{version}.dist-info/INSTALLER
rm -fv %{buildroot}/%{python3_sitelib}/%{module_name}-%{version}.dist-info/{RECORD,REQUESTED}

%pre server
getent group %{pkg_user} >/dev/null || groupadd -r %{pkg_user}
getent passwd %{pkg_user} >/dev/null || \
    useradd -r -g %{pkg_user} -d %{_sharedstatedir}/ansible-automation-platform/eda -s %{_bindir}/bash %{pkg_user}

%post
usermod -aG redis,nginx %{pkg_user}
systemctl restart rsyslog
systemctl restart logrotate

%postun
systemctl restart rsyslog
systemctl restart logrotate

%files
%defattr(-,root,root)
%{_unitdir}/automation-eda-controller.service
%{_unitdir}/automation-eda-controller-worker@.service
%{_unitdir}/automation-eda-controller.socket
%{_unitdir}/automation-eda-controller-daphne.service
%{_unitdir}/automation-eda-controller-worker.target
%{_unitdir}/automation-eda-controller.target
%attr(0755,%{pkg_user},nginx) %{_rundir}/ansible-automation-platform/eda
%{_sysconfdir}/tmpfiles.d/automation-eda-controller.conf
%{_sysconfdir}/rsyslog.d/50-automation-eda-controller.conf
%{_sysconfdir}/logrotate.d/automation-eda-controller
%{_localstatedir}/log/ansible-automation-platform/eda

%files ui
%defattr(-,root,root)
%doc ../../BUILD/%{ui_name}-%{commitId_ui}/README.md
%license ../../BUILD/%{ui_name}-%{commitId_ui}/LICENSE.md
%attr(0755,root,nginx) %{_sharedstatedir}/ansible-automation-platform/eda/ui

%files server
%defattr(-,root,root)
%doc README.md
%license LICENSE
%{_bindir}/aap-eda-manage
%{python3_sitelib}/%{module_name}
%{python3_sitelib}/%{module_name}-%{version}.dist-info
%attr(0755,%{pkg_user},%{pkg_user}) %{_sharedstatedir}/ansible-automation-platform/eda
%attr(0775,%{pkg_user},root) %{_sharedstatedir}/ansible-automation-platform/eda/media
%exclude %{_sharedstatedir}/ansible-automation-platform/eda/ui
%attr(0750,%{pkg_user},root) %{_sysconfdir}/ansible-automation-platform/eda

%changelog
* Tue Jun 13 2023 James Marshall <jamarsha@redhat.com> 1.0.0
- Initial release
